import type { Node, GatsbyNode } from "gatsby";
export interface IRemoteFileNode extends Node {
    url: string;
    mimeType: string;
    filename: string;
    filesize?: number;
}
export interface IRemoteImageNode extends IRemoteFileNode {
    width: number;
    height: number;
    placeholderUrl?: string;
}
declare type GraphqlType<T> = T extends number ? "Int" | "Float" : T extends boolean ? "Boolean" : string;
export interface IGraphQLFieldConfigDefinition<TSource, R, TArgs = Record<string, unknown>> {
    type: string;
    description?: string;
    args?: {
        [Property in keyof TArgs]: GraphqlType<TArgs[Property]> | {
            type: GraphqlType<TArgs[Property]>;
            description?: string;
            defaultValue?: TArgs[Property];
        };
    };
    resolve(source: TSource, args: TArgs): R;
}
export declare type SchemaBuilder = Parameters<NonNullable<GatsbyNode["createSchemaCustomization"]>>[0]["schema"];
export declare type ImageFit = import("sharp").FitEnum[keyof import("sharp").FitEnum];
export declare type ImageFormat = "jpg" | "png" | "webp" | "avif" | "auto";
export declare type ImageLayout = "fixed" | "constrained" | "fullWidth";
export declare type ImageCropFocus = "center" | "top" | "right" | "bottom" | "left" | "entropy" | "edges" | "faces";
export declare type WidthOrHeight = {
    width: number;
    height: number;
} | {
    width: number;
    height?: never;
} | {
    width?: never;
    height: number;
};
export declare type CalculateImageSizesArgs = {
    fit: ImageFit;
    layout: ImageLayout;
    outputPixelDensities: Array<number>;
    breakpoints?: Array<number>;
    aspectRatio?: number;
} & WidthOrHeight;
export declare function isImage(node: {
    mimeType: IRemoteFileNode["mimeType"];
}): node is IRemoteImageNode;
export {};
